@@ -5,6 +5,7 @@ from unittest import TestCase
 from freezegun import freeze_time
 from jinja2.exceptions import UndefinedError
 from more_itertools import first_true
+from os2mo_helpers.mora_helpers import MoraHelper
 from parameterized import parameterized
 from ra_utils.lazy_dict import LazyDict
 
@@ -17,7 +18,8 @@ from ..ad_writer import ADWriter
 from ..ad_writer import LoraCacheSource
 from ..user_names import UserNameSetInAD
 from ..utils import AttrDict
-from .mocks import MockADParameterReader
+from .mocks import MO_UUID
+from .mocks import MockADWriterContext
 from .mocks import MockMORESTSource
 from .test_utils import dict_modifier
 from .test_utils import mo_modifier
@@ -864,7 +866,7 @@ class TestADWriter(TestCase, TestADWriterMixin):
         uuid = "some_uuid_here"
 
         def get_mo_values(firstname, surname, nickname_firstname, nickname_surname):
-            self.user = {
+            user = {
                 "uuid": "some_uuid_here",
                 "navn": "some_name some_lastname",
                 "efternavn": surname,
@@ -874,15 +876,13 @@ class TestADWriter(TestCase, TestADWriterMixin):
                 "kaldenavn_efternavn": nickname_surname,
                 "cpr": "some_cpr",
             }
-            self.lc = AttrDict(
+            mock_lora_cache = AttrDict(
                 {
-                    "users": {
-                        self.user["uuid"]: [self.user],
-                    },
+                    "users": {user["uuid"]: [user]},
                     "engagements": {
                         "engagement_uuid": [
                             {
-                                "user": self.user["uuid"],
+                                "user": user["uuid"],
                                 "primary_boolean": True,
                                 "user_key": "some_userkey",
                                 "job_function": "job_function_title_uuid",
@@ -923,12 +923,12 @@ class TestADWriter(TestCase, TestADWriterMixin):
                     },
                 }
             )
-            self.lc_historic = self.lc
-            self.ad_writer.lc = self.lc
-            self.ad_writer.lc_historic = self.lc_historic
+            self.ad_writer.helper = mock.MagicMock(spec=MoraHelper)
+            self.ad_writer.lc = mock_lora_cache
+            self.ad_writer.lc_historic = mock_lora_cache
             self.ad_writer.datasource = LoraCacheSource(
-                self.lc,
-                self.lc_historic,
+                mock_lora_cache,  # lc
+                mock_lora_cache,  # lc_historic
                 MockMORESTSource(from_date=None, to_date=None),
             )
             mo_values = self.ad_writer._read_ad_information_from_mo(uuid)
@@ -1015,8 +1015,82 @@ class TestADWriter(TestCase, TestADWriterMixin):
         assert_adwriter_get_ad_user_raises("user", SamAccountNameNotUnique)
         assert_adwriter_get_ad_user_raises("cpr", CprNotNotUnique)
 
+    def test_other_attributes_skip_empty(self):
+        # Configure template which tries to write `mo_values['foobar']` to the
+        # 'fooBar' AD field.
+        self._setup_adwriter(
+            early_transform_settings=self._add_to_template_to_ad_fields(
+                "fooBar",
+                "{{ mo_values['foobar'] }}",
+            ),
+        )
 
-class TestInitNameCreator(TestCase):
+        # Build `mo_values` containing an *empty* 'foobar' key
+        mo_values = self._prepare_mo_values(
+            mo_values_transformer=mo_modifier({"foobar": None})
+        )
+
+        # Render "New-ADUser" command using `mo_values`
+        ps_script = self.ad_writer._get_create_user_command(mo_values, "sam")
+
+        # Assert the command does not try to set "fooBar"="None"
+        self.assertNotIn('"fooBar"="None"', ps_script)
+
+    @parameterized.expand(
+        [
+            # Case 1: test that the old "search_base" setting is used if the
+            # new setting "new_ad_user_path" is not provided.
+            (
+                {
+                    "integrations.ad": [
+                        {
+                            "search_base": "custom_search_path",
+                            # We need to provide these to make
+                            # `_read_global_settings` pass.
+                            "system_user": "system_user",
+                            "password": "password",
+                            # We need to provide this to make
+                            # `_read_primary_ad_settings` pass.
+                            "cpr_field": "cpr_field",
+                        }
+                    ]
+                },
+                "custom_search_path",
+            ),
+            # Case 2: test that the new "new_ad_user_path" settings is used, if
+            # it is provided.
+            (
+                {"integrations.ad_writer.new_ad_user_path": "custom_ad_path"},
+                "custom_ad_path",
+            ),
+        ]
+    )
+    def test_new_ad_user_path_setting_is_used(self, settings, expected_path_argument):
+        self._setup_adwriter(early_transform_settings=dict_modifier(settings))
+
+        # Test `_get_new_ad_user_path_argument`
+        path_argument = self.ad_writer._get_new_ad_user_path_argument()
+        self.assertRegex(path_argument, f' -Path "{expected_path_argument}"')
+
+        # Test `_get_create_user_command` - the `ps_script` must end with a
+        # "-Path" argument matching our expected path argument.
+        mock_mo_user = mock.MagicMock()
+        ps_script = self.ad_writer._get_create_user_command(
+            mock_mo_user, "sam_account_name"
+        )
+        self.assertRegex(ps_script, f'.* -Path "{expected_path_argument}"$')
+
+
+class _TestRealADWriter(TestCase):
+    def _prepare_adwriter(self, **kwargs):
+        template_to_ad_fields = kwargs.pop("template_to_ad_fields", {})
+        with MockADWriterContext(template_to_ad_fields=template_to_ad_fields):
+            instance = ADWriter(**kwargs)
+            instance.get_from_ad = lambda *_args, **_kwargs: {}
+            return instance
+
+
+class TestInitNameCreator(_TestRealADWriter):
     """Test `ADWriter._init_name_creator`.
 
     In this test, we instantiate the 'real' `ADWriter` rather than the
@@ -1050,23 +1124,72 @@ class TestInitNameCreator(TestCase):
         self.assertSetEqual(ad_writer.name_creator.occupied_names, set())
         self.assertEqual(len(ad_writer.name_creator._loaded_occupied_name_sets), 0)
 
-    def _prepare_adwriter(self, **kwargs):
-        # Mock enough of `ADWriter` dependencies to allow it to instantiate in
-        # a test.
 
-        all_settings = {"primary": {"method": "ntlm"}, "global": mock.MagicMock()}
-        path_prefix = "integrations.ad_integration"
-        with mock.patch(
-            f"{path_prefix}.ad_common.read_settings",
-            return_value=all_settings,
-        ):
-            with mock.patch(
-                f"{path_prefix}.ad_writer.ADWriter._create_session",
-                return_value=mock.MagicMock(),
-            ):
-                with mock.patch(f"{path_prefix}.ad_writer.MORESTSource"):
-                    with mock.patch(
-                        f"{path_prefix}.user_names.ADParameterReader",
-                        return_value=MockADParameterReader(),
-                    ):
-                        return ADWriter(**kwargs)
+class TestSyncCompare(_TestRealADWriter):
+    def test_compare_fields_converts_ad_list(self):
+        """Some AD fields contain one-element lists, rather than the usual strings,
+        numbers or UUIDs.
+
+        In such cases, we "unpack" the single-element list before comparing it to the
+        corresponding MO value - otherwise the comparison will not work as expected.
+
+        See: #47148
+        """
+        # Arrange
+        mo_value = "mo_value"
+        ad_list_element = "ad_list_element"
+        ad_user = {"ad_field_name": [ad_list_element]}
+        ad_writer = self._prepare_adwriter()
+        # Act
+        mismatch = ad_writer._compare_fields("ad_field_name", mo_value, ad_user)
+        # Assert
+        self.assertIn("ad_field_name", mismatch)
+        self.assertEqual(mismatch["ad_field_name"], (ad_list_element, mo_value))
+
+
+class TestPreview(_TestRealADWriter):
+    def test_preview_create_command(self):
+        ad_writer = self._prepare_adwriter()
+        create_cmds = ad_writer._preview_create_command(MO_UUID)
+        self.assertEqual(len(create_cmds), 2)
+        self.assertIn("New-ADUser", create_cmds[0])
+        self.assertIn("Set-ADUser -Manager", create_cmds[1])
+
+    def test_preview_sync_command(self):
+        ad_writer = self._prepare_adwriter()
+        sync_cmd, rename_cmd, rename_cmd_target = ad_writer._preview_sync_command(
+            MO_UUID, "user_sam"
+        )
+        # Examine 'sync_cmd'
+        self.assertIn("Get-ADUser", sync_cmd)
+        self.assertIn("Set-ADUser", sync_cmd)
+        # Examine 'rename_cmd'
+        self.assertIn("Get-ADUser", rename_cmd)
+        self.assertIn("Rename-ADobject", rename_cmd)
+        self.assertIn('-NewName "<new name>"', rename_cmd)
+        self.assertEqual("<nonexistent AD user>", rename_cmd_target)
+
+
+class TestJinjaEnv(_TestRealADWriter):
+    _template_to_ad_fields = {
+        "someAdField": "{{ mo_values['employee_addresses']|first_address_of_type('address-type-uuid') }}"
+    }
+    _expected_fragment = '"someAdField"="address-value"'
+
+    def test_jinja_env_has_template_filter_first_address_of_type(self):
+        ad_writer = self._prepare_adwriter()
+        self.assertIn("first_address_of_type", ad_writer._environment.filters)
+
+    def test_first_address_of_type_in_create_user_command(self):
+        ad_writer = self._prepare_adwriter(
+            template_to_ad_fields=self._template_to_ad_fields
+        )
+        create_cmd, _ = ad_writer._preview_create_command(MO_UUID)
+        self.assertIn(self._expected_fragment, create_cmd)
+
+    def test_first_address_of_type_in_sync_user_command(self):
+        ad_writer = self._prepare_adwriter(
+            template_to_ad_fields=self._template_to_ad_fields
+        )
+        sync_cmd, _, _ = ad_writer._preview_sync_command(MO_UUID, "user_sam")
+        self.assertIn(self._expected_fragment, sync_cmd)
