@@ -4,7 +4,6 @@ from unittest.mock import patch
 from helpers import dummy_settings
 from sqlalchemy.orm import sessionmaker
 
-from constants import AD_it_system
 from exporters.sql_export.lc_for_jobs_db import get_engine
 from exporters.sql_export.sql_table_defs import Adresse
 from exporters.sql_export.sql_table_defs import Base
@@ -16,6 +15,8 @@ from exporters.sql_export.sql_table_defs import Tilknytning
 from integrations.os2sync.lcdb_os2mo import get_sts_user
 from integrations.os2sync.lcdb_os2mo import try_get_ad_user_key
 
+AD_IT_SYSTEM = "Active Directory"
+
 
 class Tests_lc_db(unittest.TestCase):
     def setUp(self):
@@ -34,7 +35,7 @@ class Tests_lc_db(unittest.TestCase):
             cpr="cpr1",
         )
         self.session.add(bruger)
-        it = ItSystem(navn=AD_it_system, uuid="ItSystem1")
+        it = ItSystem(navn=AD_IT_SYSTEM, uuid="ItSystem1")
         self.session.add(it)
         it = ItSystem(navn="it_navn2", uuid="ItSystem2")
         self.session.add(it)
@@ -150,7 +151,12 @@ class Tests_lc_db(unittest.TestCase):
 
     def test_lcdb_get_ad(self):
         expected = "AD-logon"
-        self.assertEqual(expected, try_get_ad_user_key(session=self.session, uuid="b1"))
+        self.assertEqual(
+            expected,
+            try_get_ad_user_key(
+                session=self.session, uuid="b1", user_key_it_system_name=AD_IT_SYSTEM
+            ),
+        )
 
     @patch("integrations.os2sync.os2mo.org_unit_uuids", return_value={})
     def test_lcdb_get_sts_user_default(self, allowed_unitids_mock):
